<div class="panel-heading clearfix" data-toggle="collapse" data-parent="#jobs" href="#{{ type }}">

    <a class="panel-title collapsed">{{ type|title }} Jobs
        <span class="badge" title="{{ list|length }} {{ type }} jobs" data-toggle="tooltip">{{ list|length }}</span>
    </a>
</div>