{% extends "index/_base.html" %}

{% block content %}

    {{ super() }}

    <div class="panel-group" id="jobs">

        {# The type can be 'pending', 'running' and 'finished'. #}
        {# The list is a list of jobs with certain type. #}
        {% for type, list in jobs.items() %}

            <div class="panel panel-default">

                {% include "index/_jobs_panel_head.html" %}

                {% include "index/_jobs_panel_body.html" %}
            </div>
        {% endfor %}
    </div>
{% endblock %}