/* Remvoe body top padding since header exists. */
body {
    padding-top: 0px;
}

/* Remvoe top margin of page header. */
.page-header {
    margin-top: 0px;
}

/* Add bottom margin of nav-tabs. */
.nav-tabs {
    margin-bottom: 30px;
}

/* Update badge color to green. */
.panel-default > .panel-heading .badge {
    background-color: #1abc9c;
}

/* Add left and right padding of table. */
.table > tbody > tr > td:nth-of-type(1),
.table > thead > tr > td:nth-of-type(1){
    padding-left:20px;
}

.table > tbody > tr > td:nth-last-of-type(1),
.table > thead > tr > td:nth-last-of-type(1){
    padding-right:20px;
}

/* Make table font smaller. */
table {
    font-size: 15px;
}

/* Change dropdown menu minimal width in Flat-UI. */
.dropdown-menu {
    min-width: 128px
}

/* Fill dropdown menu botton to li element and align left. */
li > button.btn {
    width: 100%;
    text-align: left;
}
